@@ -947,44 +947,45 @@ class StaticConfiguration:
     def get_error(self):
         return self.get_error_kirchhoff_rules(), self.get_error_winding_rules()
 
-    def plot(self, show_vortices=True, vortex_diameter=0.25, vortex_color=(0, 0, 0),
-             anti_vortex_color=(0.8, 0.1, 0.2), vortex_alpha=1, show_grid=True, grid_width=1,
-             grid_color=(0.3, 0.5, 0.9), grid_alpha=0.5, show_colorbar=True, show_arrows=True,
-             arrow_quantity="I", arrow_width=0.005, arrow_scale=1, arrow_headwidth=3, arrow_headlength=5,
-             arrow_headaxislength=4.5, arrow_minshaft=1, arrow_minlength=1, arrow_color=(0.2, 0.4, 0.7),
-             arrow_alpha=1, show_nodes=True, node_diameter=0.2,
-             node_face_color=(1, 1, 1), node_edge_color=(0, 0, 0), node_alpha=1, show_node_quantity=False,
-             node_quantity="phase", node_quantity_cmap=None, node_quantity_clim=(0, 1), node_quantity_alpha=1,
-             node_quantity_logarithmic_colors=False, show_face_quantity=False, face_quantity="n",
-             face_quantity_cmap=None, face_quantity_clim=(0, 1), face_quantity_alpha=1,
+    def plot(self, node_quantity=None, junction_quantity="I", face_quantity=None,
+             vortex_quantity="n", show_grid=True, show_nodes=True, show_colorbar=True,
+             figsize=None, title="",
+             grid_color=(0.3, 0.5, 0.9), grid_alpha=0.5, grid_width=1,
+             node_face_color=(1, 1, 1), node_edge_color=(0, 0, 0), node_alpha=1,
+             node_quantity_cmap=None, node_quantity_clim=None, node_quantity_alpha=1,
+             node_quantity_logarithmic_colors=False,
+             arrow_width=0.005, arrow_scale=1, arrow_headwidth=3, arrow_headlength=5,
+             arrow_headaxislength=4.5, arrow_minshaft=1, arrow_minlength=1,
+             arrow_color=(0.2, 0.4, 0.7), arrow_alpha=1, node_diameter=0.2,
+             face_quantity_cmap=None, face_quantity_clim=None, face_quantity_alpha=1,
              face_quantity_logarithmic_colors=False,
-             figsize=None, title="", **kwargs):
+             vortex_diameter=0.25, vortex_color=(0, 0, 0), anti_vortex_color=(0.8, 0.1, 0.2),
+             vortex_alpha=1):
         """
         See CircuitPlot for documentation.
         """
-        from pyjjasim.circuit_visualize import CircuitPlot
+        from pyjjasim.circuit_visualize import ConfigPlot
 
-        return CircuitPlot(self, show_vortices=show_vortices, vortex_diameter=vortex_diameter,
-                         vortex_color=vortex_color, anti_vortex_color=anti_vortex_color,
-                         vortex_alpha=vortex_alpha, show_grid=show_grid, grid_width=grid_width,
-                         grid_color=grid_color, grid_alpha=grid_alpha, show_colorbar=show_colorbar,
-                         show_arrows=show_arrows,
-                         arrow_quantity=arrow_quantity, arrow_width=arrow_width, arrow_scale=arrow_scale,
-                         arrow_headwidth=arrow_headwidth, arrow_headlength=arrow_headlength,
-                         arrow_headaxislength=arrow_headaxislength, arrow_minshaft=arrow_minshaft,
-                         arrow_minlength=arrow_minlength, arrow_color=arrow_color,
-                         arrow_alpha=arrow_alpha,
-                         show_nodes=show_nodes, node_diameter=node_diameter,
-                         node_face_color=node_face_color, node_edge_color=node_edge_color,
-                         node_alpha=node_alpha, show_node_quantity=show_node_quantity,
-                         node_quantity=node_quantity, node_quantity_cmap=node_quantity_cmap,
-                         node_quantity_clim=node_quantity_clim, node_quantity_alpha=node_quantity_alpha,
-                         node_quantity_logarithmic_colors=node_quantity_logarithmic_colors,
-                         show_face_quantity=show_face_quantity, face_quantity=face_quantity,
-                         face_quantity_cmap=face_quantity_cmap, face_quantity_clim=face_quantity_clim,
-                         face_quantity_alpha=face_quantity_alpha,
-                         face_quantity_logarithmic_colors=face_quantity_logarithmic_colors,
-                         figsize=figsize, title=title, **kwargs).make()
+        return ConfigPlot(self, vortex_quantity=vortex_quantity, vortex_diameter=vortex_diameter,
+                          vortex_color=vortex_color, anti_vortex_color=anti_vortex_color,
+                          vortex_alpha=vortex_alpha, show_grid=show_grid, grid_width=grid_width,
+                          grid_color=grid_color, grid_alpha=grid_alpha, show_colorbar=show_colorbar,
+                          junction_quantity=junction_quantity, arrow_width=arrow_width, arrow_scale=arrow_scale,
+                          arrow_headwidth=arrow_headwidth, arrow_headlength=arrow_headlength,
+                          arrow_headaxislength=arrow_headaxislength, arrow_minshaft=arrow_minshaft,
+                          arrow_minlength=arrow_minlength, arrow_color=arrow_color,
+                          arrow_alpha=arrow_alpha,
+                          show_nodes=show_nodes, node_diameter=node_diameter,
+                          node_face_color=node_face_color, node_edge_color=node_edge_color,
+                          node_alpha=node_alpha,
+                          node_quantity=node_quantity, node_quantity_cmap=node_quantity_cmap,
+                          node_quantity_clim=node_quantity_clim, node_quantity_alpha=node_quantity_alpha,
+                          node_quantity_logarithmic_colors=node_quantity_logarithmic_colors,
+                          face_quantity=face_quantity,
+                          face_quantity_cmap=face_quantity_cmap, face_quantity_clim=face_quantity_clim,
+                          face_quantity_alpha=face_quantity_alpha,
+                          face_quantity_logarithmic_colors=face_quantity_logarithmic_colors,
+                          figsize=figsize, title=title).make()
 
     def report(self):
         print("Kirchhoff rules error:    ", self.get_error_kirchhoff_rules())
